--- sections_trans.cc.orig	2009-08-18 02:32:50.000000000 +0200
+++ sections_trans.cc	2009-08-18 02:33:23.000000000 +0200
@@ -44,8 +44,8 @@
    {"gnustep", _("Gnustep Desktop Environment")},
    // TRANSLATORS: Alias for the Debian package section "hamradio"
    {"hamradio", _("Amateur Radio")},
-   // TRANSLATORS: Alias for the Debian package section "haskel"
-   {"haskel", _("Haskel Programming Language")},
+   // TRANSLATORS: Alias for the Debian package section "haskell"
+   {"haskell", _("Haskell Programming Language")},
    // TRANSLATORS: Alias for the Debian package section "httpd"
    {"httpd", _("Web servers")},
    // TRANSLATORS: Alias for the Debian package section "interpreters"
